@@ -9,7 +9,7 @@ class MySQLConfig:
         import re
         if url:
             result = re.search(
-                "^(mysql://){0,1}([^:/]+)(:(\d+)){0,1}(/([^?]+)){0,1}(\?(.*)){0,1}", url)
+                "^(mysql://){0,1}([^:/]+)(:(\d+)){0,1}(/([^?]*)){0,1}(\?(.*)){0,1}", url)
             groups = result.groups()
             if not host:
                 host = groups[1] if groups[1] else self.default_host
@@ -23,7 +23,7 @@ class MySQLConfig:
             if not user:
                 user = param.get("user")
             if not password:
-                user = param.get("password")
+                password = param.get("password")
 
         self.url = url
         self.host = host
@@ -33,6 +33,24 @@ class MySQLConfig:
         self.user = user
         self.password = password
 
+    def to_dict(self):
+        d = {}
+        if self.url is not None:
+            d["url"] = self.url
+        if self.host is not None:
+            d["host"] = self.host
+        if self.port is not None:
+            d["port"] = self.port
+        if self.database is not None:
+            d["database"] = self.database
+        if self.param is not None:
+            d["param"] = self.param
+        if self.user is not None:
+            d["user"] = self.user
+        if self.password is not None:
+            d["password"] = self.password
+        return d
+
     def __eq__(self, value):
         return self.host == value.host and self.port == value.port and self.database == value.database and self.param == value.param and self.user == value.user and self.password == value.password
 
@@ -75,6 +93,30 @@ def mysql_insert(client, sql):
     return cursor.lastrowid if res else 0
 
 
+def mysql_iter_table(client, table, where_condition="", offset_limit=""):
+    if where_condition:
+        if not where_condition.startswith("where") and not where_condition.startswith("WHERE"):
+            where_condition = "where "+where_condition
+    sql = f"select * from {table} {where_condition} {offset_limit}"
+    from pymysql.cursors import SSDictCursor
+    cursor = SSDictCursor(client)
+    cursor.execute(sql)
+    while True:
+        item = cursor.fetchone()
+        if not item:
+            cursor.close()
+            return
+        yield item
+
+
+def mysql_count_table(client, table, where_condition="", offset_limit=""):
+    if where_condition:
+        if not where_condition.startswith("where") and not where_condition.startswith("WHERE"):
+            where_condition = "where "+where_condition
+    sql = f"select count(*) from {table} {where_condition} {offset_limit}"
+    return mysql_query_one_value(client, sql)
+
+
 class ZMySQL:
     def __init__(self, url=None):
         self.client = mysql_connect(url=url)
